@@ -78,6 +78,11 @@ class CreatorTestCase(unittest.TestCase):
         self.assertTrue(self.portal["another-image"].image.filename, "image.png")
         self.assertTrue(self.portal["another-image"].image.contentType, "image/png")
 
+        self.assertIn("image-svg", self.portal.objectIds())
+        self.assertTrue(self.portal["image-svg"].image)
+        self.assertTrue(self.portal["image-svg"].image.filename, "image.svg")
+        self.assertTrue(self.portal["image-svg"].image.contentType, "image/svg")
+
         self.assertIn("news-item-image", self.portal.objectIds())
         self.assertTrue(self.portal["news-item-image"].image)
         self.assertTrue(self.portal["news-item-image"].image.filename, "image.png")
@@ -149,6 +154,8 @@ class CreatorTestCase(unittest.TestCase):
 
         self.portal.invokeFactory("Folder", "a-folder")
         self.assertIn("a-folder", self.portal.objectIds())
+        self.portal.invokeFactory("Folder", "a-folder-with-no-id")
+        self.assertIn("a-folder-with-no-id", self.portal.objectIds())
 
         with api.env.adopt_roles(["Manager"]):
             create_item_runner(
@@ -159,6 +166,9 @@ class CreatorTestCase(unittest.TestCase):
             )
 
         self.assertEqual(self.portal["a-folder"].description, "The description")
+        self.assertEqual(
+            self.portal["a-folder-with-no-id"].description, "The description edited"
+        )
 
     def test_content_from_folder(self):
         path = os.path.join(os.path.dirname(__file__), "content")
